==> showimg_0.7.orig.tar.gz: showimg-0.7.orig/showimg/ProgressDialog.h <==
/***************************************************************************
                          ProgressDialog.h  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __PROGRESSDIALOG_H__
#define __PROGRESSDIALOG_H__

// QT Includes
#include <qprogressdialog.h>
#include <qlayout.h>
#include <qmultilineedit.h>
#include <qpushbutton.h>
#include <qprogressbar.h>

class ProgressDialog : public QProgressDialog
{ 
    Q_OBJECT

    public:
        ProgressDialog( QWidget* parent = 0, bool p = false, const char* name = 0, bool modal =
            FALSE, WFlags fl = 0 );
        ~ProgressDialog();
        void print( QString text );
	void ProgressDialog::print(QString in, QString out );
	void inc();
	void init( int numOfFiles );
    private slots:
        void quitAll();
    protected:
        bool preview;
	int done;
};

#endif // __PROGRESSDIALOG_H__

==> showimg_0.9.1.orig.tar.gz: showimg-0.9.1/showimg/ProgressDialog.h <==
/***************************************************************************
                          ProgressDialog.h  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __PROGRESSDIALOG_H__
#define __PROGRESSDIALOG_H__

// QT Includes
#include <qprogressdialog.h>
#include <qlayout.h>
#include <qmultilineedit.h>
#include <qpushbutton.h>
#include <qprogressbar.h>

class ProgressDialog : public QProgressDialog
{ 
    Q_OBJECT

    public:
        ProgressDialog( QWidget* parent = 0, bool p = false, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
        ~ProgressDialog();
	
	void print(QString in, QString out="");
	void inc();
	void init( int numOfFiles );
	
    private slots:
        void quitAll();
	
    protected:
        bool preview;
	int done;
};

#endif // __PROGRESSDIALOG_H__
